package org.eclipse.scout.demo.view.client.ui.forms;

import org.eclipse.scout.commons.annotations.FormData;
import org.eclipse.scout.commons.annotations.Order;
import org.eclipse.scout.commons.exception.ProcessingException;
import org.eclipse.scout.demo.view.client.ui.forms.BottomForm.MainBox.BottomField;
import org.eclipse.scout.demo.view.client.ui.forms.BottomForm.MainBox.NoteField;
import org.eclipse.scout.demo.view.shared.Icons;
import org.eclipse.scout.demo.view.shared.Texts;
import org.eclipse.scout.demo.view.shared.security.UpdateBottomPermission;
import org.eclipse.scout.demo.view.shared.services.process.BottomFormData;
import org.eclipse.scout.demo.view.shared.services.process.IBottomProcessService;
import org.eclipse.scout.rt.client.ui.form.AbstractForm;
import org.eclipse.scout.rt.client.ui.form.AbstractFormHandler;
import org.eclipse.scout.rt.client.ui.form.fields.groupbox.AbstractGroupBox;
import org.eclipse.scout.rt.client.ui.form.fields.labelfield.AbstractLabelField;
import org.eclipse.scout.rt.client.ui.form.fields.stringfield.AbstractStringField;
import org.eclipse.scout.service.SERVICES;

@FormData(value = BottomFormData.class, sdkCommand = FormData.SdkCommand.CREATE)
public class BottomForm extends AbstractForm {

  private Long bottomNr;

  public BottomForm() throws ProcessingException {
    super();
  }

  @Override
  protected boolean getConfiguredAskIfNeedSave() {
    return false;
  }

  @Override
  protected int getConfiguredDisplayHint() {
    return DISPLAY_HINT_VIEW;
  }

  @Override
  protected String getConfiguredDisplayViewId() {
    return VIEW_ID_S;
  }

  @Override
  protected String getConfiguredIconId() {
    return Icons.EclipseScout;
  }

  @Override
  protected String getConfiguredTitle() {
    return Texts.get("Bottom");
  }

  @FormData
  public Long getBottomNr() {
    return bottomNr;
  }

  @FormData
  public void setBottomNr(Long bottomNr) {
    this.bottomNr = bottomNr;
  }

  public void startModify() throws ProcessingException {
    startInternal(new BottomForm.ModifyHandler());
  }

  public MainBox getMainBox() {
    return getFieldByClass(MainBox.class);
  }

  public BottomField getBottomField() {
    return getFieldByClass(BottomField.class);
  }

  public NoteField getNoteField() {
    return getFieldByClass(NoteField.class);
  }

  @Order(10.0)
  public class MainBox extends AbstractGroupBox {

    @Override
    protected int getConfiguredGridColumnCount() {
      return 1;
    }

    @Order(10.0)
    public class BottomField extends AbstractLabelField {

      @Override
      protected String getConfiguredFont() {
        return "BOLD";
      }

      @Override
      protected boolean getConfiguredLabelVisible() {
        return false;
      }

      @Override
      protected void execInitField() throws ProcessingException {
        setValue(Texts.get("Bottom"));
      }
    }

    @Order(20.0)
    public class NoteField extends AbstractStringField {

      @Override
      protected int getConfiguredGridH() {
        return 2;
      }

      @Override
      protected String getConfiguredLabel() {
        return Texts.get("Note");
      }

      @Override
      protected int getConfiguredLabelPosition() {
        return LABEL_POSITION_ON_FIELD;
      }

      @Override
      protected boolean getConfiguredMultilineText() {
        return true;
      }

      @Override
      protected boolean getConfiguredWrapText() {
        return true;
      }
    }
  }

  public class ModifyHandler extends AbstractFormHandler {

    @Override
    public void execLoad() throws ProcessingException {
      IBottomProcessService service = SERVICES.getService(IBottomProcessService.class);
      BottomFormData formData = new BottomFormData();
      exportFormData(formData);
      formData = service.load(formData);
      importFormData(formData);
      setEnabledPermission(new UpdateBottomPermission());
    }

    @Override
    public void execStore() throws ProcessingException {
      IBottomProcessService service = SERVICES.getService(IBottomProcessService.class);
      BottomFormData formData = new BottomFormData();
      exportFormData(formData);
      formData = service.store(formData);
    }
  }

}
