package org.eclipse.scout.demo.view.client.ui.forms;

import org.eclipse.scout.commons.annotations.FormData;
import org.eclipse.scout.commons.annotations.Order;
import org.eclipse.scout.commons.exception.ProcessingException;
import org.eclipse.scout.demo.view.client.ui.forms.DesktopForm.MainBox.SomeFieldsBox;
import org.eclipse.scout.demo.view.client.ui.forms.DesktopForm.MainBox.SomeFieldsBox.ASequenceBox;
import org.eclipse.scout.demo.view.client.ui.forms.DesktopForm.MainBox.SomeFieldsBox.ASequenceBox.ASequenceFrom;
import org.eclipse.scout.demo.view.client.ui.forms.DesktopForm.MainBox.SomeFieldsBox.ASequenceBox.ASequenceTo;
import org.eclipse.scout.demo.view.client.ui.forms.DesktopForm.MainBox.SomeFieldsBox.ASmartField;
import org.eclipse.scout.demo.view.client.ui.forms.DesktopForm.MainBox.SomeFieldsBox.ATextField;
import org.eclipse.scout.demo.view.shared.Icons;
import org.eclipse.scout.demo.view.shared.Texts;
import org.eclipse.scout.demo.view.shared.services.process.DesktopFormData;
import org.eclipse.scout.demo.view.shared.services.process.IDesktopProcessService;
import org.eclipse.scout.rt.client.ui.form.AbstractForm;
import org.eclipse.scout.rt.client.ui.form.AbstractFormHandler;
import org.eclipse.scout.rt.client.ui.form.fields.datefield.AbstractDateField;
import org.eclipse.scout.rt.client.ui.form.fields.groupbox.AbstractGroupBox;
import org.eclipse.scout.rt.client.ui.form.fields.sequencebox.AbstractSequenceBox;
import org.eclipse.scout.rt.client.ui.form.fields.smartfield.AbstractSmartField;
import org.eclipse.scout.rt.client.ui.form.fields.stringfield.AbstractStringField;
import org.eclipse.scout.rt.shared.ScoutTexts;
import org.eclipse.scout.service.SERVICES;

@FormData(value = DesktopFormData.class, sdkCommand = FormData.SdkCommand.CREATE)
public class DesktopForm extends AbstractForm {

  public DesktopForm() throws ProcessingException {
    super();
  }

  @Override
  protected boolean getConfiguredAskIfNeedSave() {
    return false;
  }

  @Override
  protected int getConfiguredDisplayHint() {
    return DISPLAY_HINT_VIEW;
  }

  @Override
  protected String getConfiguredDisplayViewId() {
    return VIEW_ID_CENTER;
  }

  public ASequenceBox getASequenceBox() {
    return getFieldByClass(ASequenceBox.class);
  }

  public ASequenceFrom getASequenceFrom() {
    return getFieldByClass(ASequenceFrom.class);
  }

  public ASequenceTo getASequenceTo() {
    return getFieldByClass(ASequenceTo.class);
  }

  public ASmartField getASmartField() {
    return getFieldByClass(ASmartField.class);
  }

  public ATextField getATextField() {
    return getFieldByClass(ATextField.class);
  }

  public MainBox getMainBox() {
    return getFieldByClass(MainBox.class);
  }

  public SomeFieldsBox getSomeFieldsBox() {
    return getFieldByClass(SomeFieldsBox.class);
  }

  @Order(10.0)
  public class MainBox extends AbstractGroupBox {

    @Override
    protected int getConfiguredGridColumnCount() {
      return 1;
    }

    @Override
    protected boolean getConfiguredScrollable() {
      return true;
    }

    @Order(10.0)
    public class SomeFieldsBox extends AbstractGroupBox {

      @Override
      protected String getConfiguredBorderDecoration() {
        return BORDER_DECORATION_SECTION;
      }

      @Override
      protected String getConfiguredLabel() {
        return Texts.get("SomeFields");
      }

      @Order(10.0)
      public class ATextField extends AbstractStringField {

        @Override
        protected boolean getConfiguredFillHorizontal() {
          return false;
        }

        @Override
        protected String getConfiguredLabel() {
          return Texts.get("ATextField");
        }
      }

      @Order(20.0)
      public class ASmartField extends AbstractSmartField<Long> {

        @Override
        protected boolean getConfiguredFillHorizontal() {
          return false;
        }

        @Override
        protected String getConfiguredLabel() {
          return Texts.get("ASmartField");
        }
      }

      @Order(30.0)
      public class ASequenceBox extends AbstractSequenceBox{

        @Override
        protected boolean getConfiguredFillHorizontal() {
          return false;
        }

        @Override
        protected String getConfiguredLabel() {
          return Texts.get("ASequenceBox");
        }

        @Order(10.0)
        public class ASequenceFrom extends AbstractDateField{

          @Override
          protected String getConfiguredLabel() {
            return ScoutTexts.get("from");
          }
        }

        @Order(20.0)
        public class ASequenceTo extends AbstractDateField{

          @Override
          protected String getConfiguredLabel() {
            return ScoutTexts.get("to");
          }
        }
      }
    }

  }

  public class ViewHandler extends AbstractFormHandler {

    @Override
    protected void execLoad() throws ProcessingException {
      IDesktopProcessService service = SERVICES.getService(IDesktopProcessService.class);
      DesktopFormData formData = new DesktopFormData();
      exportFormData(formData);
      formData = service.load(formData);
      importFormData(formData);

    }
  }

  @Override
  protected String getConfiguredIconId() {
    return Icons.EclipseScout;
  }

  @Override
  protected String getConfiguredTitle() {
    return Texts.get("Center");
  }

  public void startView() throws ProcessingException {
    startInternal(new DesktopForm.ViewHandler());
  }
}
