package org.eclipse.scout.demo.view.client.ui.forms;

import org.eclipse.scout.commons.annotations.FormData;
import org.eclipse.scout.commons.annotations.Order;
import org.eclipse.scout.commons.exception.ProcessingException;
import org.eclipse.scout.demo.view.client.ui.forms.RightForm.MainBox.AListBoxField;
import org.eclipse.scout.demo.view.client.ui.forms.RightForm.MainBox.RightField;
import org.eclipse.scout.demo.view.shared.Icons;
import org.eclipse.scout.demo.view.shared.Texts;
import org.eclipse.scout.demo.view.shared.security.UpdateRightPermission;
import org.eclipse.scout.demo.view.shared.services.code.ACodeType;
import org.eclipse.scout.demo.view.shared.services.process.IRightProcessService;
import org.eclipse.scout.demo.view.shared.services.process.RightFormData;
import org.eclipse.scout.rt.client.ui.form.AbstractForm;
import org.eclipse.scout.rt.client.ui.form.AbstractFormHandler;
import org.eclipse.scout.rt.client.ui.form.fields.groupbox.AbstractGroupBox;
import org.eclipse.scout.rt.client.ui.form.fields.labelfield.AbstractLabelField;
import org.eclipse.scout.rt.client.ui.form.fields.listbox.AbstractListBox;
import org.eclipse.scout.rt.shared.services.common.code.ICodeType;
import org.eclipse.scout.service.SERVICES;

@FormData(value = RightFormData.class, sdkCommand = FormData.SdkCommand.CREATE)
public class RightForm extends AbstractForm {

  private Long rightNr;

  public RightForm() throws ProcessingException {
    super();
  }

  @Override
  protected boolean getConfiguredAskIfNeedSave() {
    return false;
  }

  @Override
  protected int getConfiguredDisplayHint() {
    return DISPLAY_HINT_VIEW;
  }

  @Override
  protected String getConfiguredDisplayViewId() {
    return VIEW_ID_E;
  }

  @Override
  protected String getConfiguredIconId() {
    return Icons.EclipseScout;
  }

  @Override
  protected String getConfiguredTitle() {
    return Texts.get("Right");
  }

  @FormData
  public Long getRightNr() {
    return rightNr;
  }

  @FormData
  public void setRightNr(Long rightNr) {
    this.rightNr = rightNr;
  }

  public void startModify() throws ProcessingException {
    startInternal(new RightForm.ModifyHandler());
  }

  public AListBoxField getAListBoxField() {
    return getFieldByClass(AListBoxField.class);
  }

  public MainBox getMainBox() {
    return getFieldByClass(MainBox.class);
  }

  public RightField getRightField() {
    return getFieldByClass(RightField.class);
  }

  @Order(10.0)
  public class MainBox extends AbstractGroupBox {

    @Override
    protected int getConfiguredGridColumnCount() {
      return 1;
    }

    @Order(10.0)
    public class RightField extends AbstractLabelField {

      @Override
      protected String getConfiguredFont() {
        return "BOLD";
      }

      @Override
      protected boolean getConfiguredLabelVisible() {
        return false;
      }

      @Override
      protected void execInitField() throws ProcessingException {
        setValue(Texts.get("Right"));
      }
    }

    @Order(20.0)
    public class AListBoxField extends AbstractListBox<Long> {

      @Override
      protected Class<? extends ICodeType> getConfiguredCodeType() {
        return ACodeType.class;
      }

      @Override
      protected int getConfiguredGridH() {
        return 2;
      }

      @Override
      protected String getConfiguredLabel() {
        return Texts.get("AListBox");
      }

      @Override
      protected boolean getConfiguredLabelVisible() {
        return false;
      }
    }
  }

  public class ModifyHandler extends AbstractFormHandler {

    @Override
    public void execLoad() throws ProcessingException {
      IRightProcessService service = SERVICES.getService(IRightProcessService.class);
      RightFormData formData = new RightFormData();
      exportFormData(formData);
      formData = service.load(formData);
      importFormData(formData);
      setEnabledPermission(new UpdateRightPermission());
    }

    @Override
    public void execStore() throws ProcessingException {
      IRightProcessService service = SERVICES.getService(IRightProcessService.class);
      RightFormData formData = new RightFormData();
      exportFormData(formData);
      formData = service.store(formData);
    }
  }

}
